@@ -115,7 +115,7 @@ def init(step=0):
                 switch_button.click()
             else:
                 continue
-            to_week = wait_and_find_element_by_xpath(browser, '//button[@name="Week"]', timeOutDelay).click()
+            to_week = wait_and_find_element_by_xpath(browser, '//button[@name="Week"]', timeOutDelay)
             if to_week:
                 to_week.click()
             else:
